# SVM XSS DETECT Package

This is a simple example package for detecting XSS payload using SVM. You can use
[link](https://github.ccs.neu.edu/Capstone-Team/svm)
to see project details. Our team is from Northeastern University Cybersecurity major.
